==> video_curator-1.1.0-py3-none-any.whl: yourtube/prompts.py <==
prompt_process_text = lambda content: f"""
[Metadata]
name: Process Transcription
description: Generate well-structured articles from raw transcription text
[/Metadata]

You are an expert editor specializing in transforming raw transcription text into a clear, coherent, and readable article. Your task is to convert the provided raw transcription text into a polished article without altering the original content. Follow these exact instructions:

### 1. Input Analysis and Language Check
- **Detect the Language:**  
  Identify the language of the provided transcription text.  
  *Note: If the detected language is Chinese, do not translate any part of the text to English.*

### 2. Content Restructuring
- **Remove Extraneous Data:**  
  - Eliminate all index numbers, timestamps, and any metadata markers.
  - Remove unnecessary line breaks, fragmented lines, and redundant spaces.
  
- **Reorganize the Text:**  
  - Combine fragmented sentences and paragraphs to form coherent, well-structured paragraphs.
  - Ensure that punctuation is correctly applied so the text flows naturally.
  
- **Maintain Original Content:**  
  - **Do not add, remove, or modify any words** from the original transcription. Your role is solely to restructure and enhance readability.

### 3. Output Requirements
- **Final Output:**  
  - Provide the transformed text as a continuous article.
  - The output must be in the same language as the input text.

### 4. Example for Clarity
**Raw Transcription Example:**

Here is the example of the raw transcription text:

'''
1
00:00:00,000 --> 00:00:08,199
我们不是没有需求,我们动过念头,我们在这需要一个什么东西。然后你往哪去求助啊。有人在上面找别人做好的软件,找不着。

2
00:00:08,199 --> 00:00:13,040
就只能找别人去问问,也有一个沟通成本。有点在内下,还不好意思问。

3
00:00:13,040 --> 00:00:18,440
坦特最近大家聊得比较多的,有一个叫做AI福祝编程。

4
00:00:18,440 --> 00:00:26,320
这个东西实际上在Chat GPD之前,人们就开始在做这么个东西。

5
00:00:26,519 --> 00:00:36,000
包括Gitlab Copilot,我们现在看到的大元模型越来越强之后,我也给你演示过,

6
00:00:36,000 --> 00:00:42,760
对吧,咱们之前聊过Cursor,咱们之前还聊过Balt,BOLT,

7
00:00:42,760 --> 00:00:46,560
然后可以一战势的开发网也应用。

8
00:00:46,560 --> 00:00:51,600
本来大家骑了柔柔,对吧?我们就说现在AI可以帮助我们来编程了,

9
00:00:51,600 --> 00:00:55,160
然后可以帮助我们解决很多的问题,我们很开心。

10
00:00:55,160 --> 00:00:59,880
原本就是这么一个事,现在突然间就搞的,很多人就跳出来,

11
00:00:59,880 --> 00:01:06,640
说AI变成这个东西,现在弄的越来越恶心,有的人已经开始用恶心这个词。
'''

**Processed Text Example:**
Here is the processed text: 
'''
我们不是没有需求,我们动过念头,我们在这需要一个什么东西。然后你往哪去求助啊。有人在上面找别人做好的软件,找不着。就只能找别人去问问,也有一个沟通成本。有点在内下,还不好意思问。坦特最近大家聊得比较多的,有一个叫做AI福祝编程。这个东西实际上在Chat GPD之前,人们就开始在做这么个东西。包括Gitlab Copilot,我们现在看到的大元模型越来越强之后,我也给你演示过,对吧,咱们之前聊过Cursor,咱们之前还聊过Balt,BOLT,然后可以一战势的开发网也应用。本来大家骑了柔柔,对吧?我们就说现在AI可以帮助我们来编程了,然后可以帮助我们解决很多的问题,我们很开心。原本就是这么一个事,现在突然间就搞的,很多人就跳出来,说AI变成这个东西,现在弄的越来越恶心,有的人已经开始用恶心这个词。
'''

### 5. Instructions Recap
- **Detect the language** of the input and ensure your final output uses the same language.
- **Eliminate indices, timestamps, and unnecessary breaks.**
- **Restructure** the text into clear, natural-flowing paragraphs while preserving the original content.
- **Do not modify or add content.**

When you are ready, process the transcription text accordingly.
<body>
{content}
</body>
"""


prompt_summarize = lambda content: f"""
You are a bilingual text summarization expert with deep fluency in both English and Chinese. Your task is to analyze a given piece of text, reorganize its information, and produce a comprehensive summary. Follow the steps below exactly:

---

### 1. Language Identification
- **Determine the language:**  
  Analyze the input text and denote the detected language as <LAN>.
- **Uniform Output:**  
  Ensure that the entire response is in <LAN>.  
  *If <LAN> is Chinese, please rewrite all contents with Chinese.*
  *If <LAN> is English, please rewrite all contents with English.*
  *（如果<LAN>是中文，请用中文重写所有内容；如果<LAN>是英文，请用英文重写所有内容）*

---

### 2. Output Structure and Format
- **Markdown Formatting:**  
  Use Markdown with bold headings and bullet lists for clarity.
- **Three Sections Required:**  
  Your final output must contain exactly three sections:
  1. **summary**
  2. **insight**
  3. **breakdown**

---

### 3. Processing Steps
- Step 1. **Breakdown Section:**
  - Conduct a comprehensive analysis of the text.
  - Identify all major topics and subtopics.
  - For each topic/subtopic, provide detailed descriptions including numbers, examples, or evidence.
  - Organize your analysis in bullet lists and sub-bullets to form the **breakdown** section.
  
- Step 2. **Summary Section:**
  - Based on your detailed analysis, create a concise summary capturing the main points.
  - This concise overview will be your **summary** section.
  
- Step 3. **Insight Section:**
  - Reflect on the information in both the **breakdown** and **summary**.
  - Draw creative conclusions or additional insights.
  - Present this reflective commentary in the **insight** section.

---

### 4. Final Verification
- **Language Consistency:**  
  Double-check that your final output is entirely in <LAN>.  
  *If <LAN> is Chinese, ensure every section is in Chinese.*

---

**Remember:**  
Below is the content to be summarized:

<body>
{content}
</body>
"""

==> video_curator-1.2.1-py3-none-any.whl: yourtube/prompts.py <==
prompt_process_text = lambda content: f"""
[Metadata]
name: Process Transcription
description: Generate well-structured articles from raw transcription text
[/Metadata]

You are an expert editor specializing in transforming raw transcription text into a clear, coherent, and readable article. Your task is to convert the provided raw transcription text into a polished article without altering the original content. Follow these exact instructions:

### 1. Input Analysis and Language Check
- **Detect the Language:**  
  Identify the language of the provided transcription text.  
  *Note: If the detected language is Chinese, do not translate any part of the text to English.*

### 2. Content Restructuring
- **Remove Extraneous Data:**  
  - Eliminate all index numbers, timestamps, and any metadata markers.
  - Remove unnecessary line breaks, fragmented lines, and redundant spaces.
  
- **Reorganize the Text:**  
  - Combine fragmented sentences and paragraphs to form coherent, well-structured paragraphs.
  - Ensure that punctuation is correctly applied so the text flows naturally.
  
- **Maintain Original Content:**  
  - **Do not add, remove, or modify any words** from the original transcription. Your role is solely to restructure and enhance readability.

### 3. Output Requirements
- **Final Output:**  
  - Provide the transformed text as a continuous article.
  - The output must be in the same language as the input text.

### 4. Example for Clarity
**Raw Transcription Example:**

Here is the example of the raw transcription text:

'''
1
00:00:00,000 --> 00:00:08,199
我们不是没有需求,我们动过念头,我们在这需要一个什么东西。然后你往哪去求助啊。有人在上面找别人做好的软件,找不着。

2
00:00:08,199 --> 00:00:13,040
就只能找别人去问问,也有一个沟通成本。有点在内下,还不好意思问。

3
00:00:13,040 --> 00:00:18,440
坦特最近大家聊得比较多的,有一个叫做AI福祝编程。

4
00:00:18,440 --> 00:00:26,320
这个东西实际上在Chat GPD之前,人们就开始在做这么个东西。

5
00:00:26,519 --> 00:00:36,000
包括Gitlab Copilot,我们现在看到的大元模型越来越强之后,我也给你演示过,

6
00:00:36,000 --> 00:00:42,760
对吧,咱们之前聊过Cursor,咱们之前还聊过Balt,BOLT,

7
00:00:42,760 --> 00:00:46,560
然后可以一战势的开发网也应用。

8
00:00:46,560 --> 00:00:51,600
本来大家骑了柔柔,对吧?我们就说现在AI可以帮助我们来编程了,

9
00:00:51,600 --> 00:00:55,160
然后可以帮助我们解决很多的问题,我们很开心。

10
00:00:55,160 --> 00:00:59,880
原本就是这么一个事,现在突然间就搞的,很多人就跳出来,

11
00:00:59,880 --> 00:01:06,640
说AI变成这个东西,现在弄的越来越恶心,有的人已经开始用恶心这个词。
'''

**Processed Text Example:**
Here is the processed text: 
'''
我们不是没有需求,我们动过念头,我们在这需要一个什么东西。然后你往哪去求助啊。有人在上面找别人做好的软件,找不着。就只能找别人去问问,也有一个沟通成本。有点在内下,还不好意思问。坦特最近大家聊得比较多的,有一个叫做AI福祝编程。这个东西实际上在Chat GPD之前,人们就开始在做这么个东西。包括Gitlab Copilot,我们现在看到的大元模型越来越强之后,我也给你演示过,对吧,咱们之前聊过Cursor,咱们之前还聊过Balt,BOLT,然后可以一战势的开发网也应用。本来大家骑了柔柔,对吧?我们就说现在AI可以帮助我们来编程了,然后可以帮助我们解决很多的问题,我们很开心。原本就是这么一个事,现在突然间就搞的,很多人就跳出来,说AI变成这个东西,现在弄的越来越恶心,有的人已经开始用恶心这个词。
'''

### 5. Instructions Recap
- **Detect the language** of the input and ensure your final output uses the same language.
- **Eliminate indices, timestamps, and unnecessary breaks.**
- **Restructure** the text into clear, natural-flowing paragraphs while preserving the original content.
- **Do not modify or add content.**

When you are ready, process the transcription text accordingly.
<body>
{content}
</body>
"""


prompt_summarize = lambda content: f"""
You are a bilingual text summarization expert with deep fluency in both English and Chinese. Your task is to analyze a given piece of text, reorganize its information, and produce a comprehensive summary. Follow the steps below exactly:

---

### 1. Language Identification
- **Determine the language:**  
  Analyze the input text and denote the detected language as <LAN>.
- **Uniform Output:**  
  Ensure that the entire response is in <LAN>.  
  *If <LAN> is Chinese, please rewrite all contents with Simplified Chinese.*
  *If <LAN> is English, please rewrite all contents with English.*
  *（如果<LAN>是中文，请用中文重写所有内容；如果<LAN>是英文，请用英文重写所有内容）*

---

### 2. Output Structure and Format
- **Markdown Formatting:**  
  Use Markdown with bold headings and bullet lists for clarity.
- **Three Sections Required:**  
  Your final output must contain exactly three sections:
  1. **summary**
  2. **insight**
  3. **breakdown**

---

### 3. Processing Steps
- Step 1. **Breakdown Section:**
  - Conduct a comprehensive analysis of the text.
  - Identify all major topics and subtopics.
  - For each topic/subtopic, provide detailed descriptions including numbers, examples, or evidence.
  - Organize your analysis in bullet lists and sub-bullets to form the **breakdown** section.
  
- Step 2. **Summary Section:**
  - Based on your detailed analysis, create a concise summary capturing the main points.
  - This concise overview will be your **summary** section.
  
- Step 3. **Insight Section:**
  - Reflect on the information in both the **breakdown** and **summary**.
  - Draw creative conclusions or additional insights.
  - Present this reflective commentary in the **insight** section.

---

### 4. Final Verification
- **Language Consistency:**  
  Double-check that your final output is entirely in <LAN>.  
  *If <LAN> is Chinese, ensure every section is in Chinese.*

---

**Remember:**  
Below is the content to be summarized:

<body>
{content}
</body>
"""


prompt_process_fulltext_zh = lambda content, starting_text: f"""
你很擅长在尊重原文的基础上重写内容。你会采用段落的形式，而不是列表的形式。你使用简体中文，而非繁体中文。你非常尊重原文，你不会对原文进行修改，仅纠正必要的错别字和汉语常用短语。

以下是你需要重写的文本：

"{content}"

请重写以上文本。开头我已经为你写好，以下为开头，开头之前的内容请忽略

"{starting_text}"
"""

prompt_process_fulltext_en = lambda content, starting_text: f"""
You excel at rewriting content while respecting the original text. You use paragraph format rather than list format. You deeply respect the original text and won't modify it, only correcting necessary typos and common phrases.

Here is the text you need to rewrite:

"{content}"

Please rewrite the text above. I have already written the beginning for you, please ignore any content before this beginning:

"{starting_text}"
"""

def prompt_process_fulltext(content, starting_text, language):
    if language == "zh":
        return prompt_process_fulltext_zh(content, starting_text)
    else:
        return prompt_process_fulltext_en(content, starting_text)
